<?php 
if( ! isset( $content_width ) )
    $content_width = 625;
function arwebstudio_setup() {
    load_theme_textdomain( 'arwebstudio', get_template_directory() . '/langs' );
    add_editor_style();
    add_theme_support( 'automatic-feed-links' );
    add_theme_support( 'post-formats', array( 'aside', 'image', 'link', 'quote', 'status' ) );
    register_nav_menu( 'menu', __( 'Main Menu', 'arwebstudio' ) );
    add_theme_support( 'custom-background', 
        array(
            'default-color' => 'a73511',
        ) 
    );

    add_theme_support( 'post-thumbnails' );

    set_post_thumbnail_size( 625, 9999 );
}
add_action( 'after_setup_theme', 'arwebstudio_setup' );

require( get_template_directory() . '/inc/custom-header.php' );

function arwebstudio_scripts_styles() {
    global $wp_styles;
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
        wp_enqueue_script( 'comment-reply' );
    wp_enqueue_script( 'arwebstudio-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '1.0', true );
    if ( 'off' !== _x( 'on', 'Source Sans Pro font: on or off', 'arwebstudio' ) ) {
        $subsets = 'latin,latin-ext';
        $subset = _x( 'no-subset', 'Source Sans Pro font: add new subset (greek, cyrillic, vietnamese)', 'arwebstudio' );
        if ( 'cyrillic' == $subset )
            $subsets .= ',cyrillic,cyrillic-ext';
        elseif ( 'greek' == $subset )
            $subsets .= ',greek,greek-ext';
        elseif ( 'vietnamese' == $subset )
            $subsets .= ',vietnamese';
        $protocol = is_ssl() ? 'https' : 'http';
        $query_args = array(
            'family' => 'Source+Sans+Pro:400italic,700italic,400,700',
            'subset' => $subsets,
        );
        wp_enqueue_style( 'arwebstudio-fonts', add_query_arg( $query_args, "$protocol://fonts.googleapis.com/css" ), array(), null );
    }
    wp_enqueue_style( 'arwebstudio-style', get_stylesheet_uri() );
    wp_enqueue_style( 'arwebstudio-ie', get_template_directory_uri() . '/css/ie.css', array( 'arwebstudio-style' ), '20130430' );
    $wp_styles->add_data( 'arwebstudio-ie', 'conditional', 'lt IE 9' );
}
add_action( 'wp_enqueue_scripts', 'arwebstudio_scripts_styles' );

function arwebstudio_wp_title( $title, $sep ) {
    global $paged, $page;
    if( is_feed() )
        return $title;
    $title .= get_bloginfo( 'name' );
    $site_description = get_bloginfo( 'description', 'display' );
    if( $site_description && ( is_home() || is_front_page() ) )
        $title = "$title $sep $site_description";
    if( $paged >= 2 || $page >= 2 )
        $title = "$title $sep " . sprintf( __( 'Page %s', 'arwebstudio' ), max( $paged, $page ) );
    return $title;
}
add_filter( 'wp_title', 'arwebstudio_wp_title', 10, 2 );

function arwebstudio_page_menu_args( $args ) {
    if( ! isset( $args['show_home'] ) )
        $args['show_home'] = true;
    return $args;
}
add_filter( 'wp_page_menu_args', 'arwebstudio_page_menu_args' );

function arwebstudio_widgets_init() {
    register_sidebar(
        array(
            'name' => __( 'Meta widget', 'arwebstudio' ),
            'id' => 'sidebar-1',
            'description' => __( 'Appears on posts and pages except the optional Front Page template, which has its own widgets', 'arwebstudio' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>'
        )
    );
    register_sidebar(
        array(
            'name' => __( 'Tag Cloud widget', 'arwebstudio' ),
            'id' => 'sidebar-2',
            'description' => __( 'Appears when using the optional Front Page template with a page set as Static Front Page', 'arwebstudio' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>'
        )
    );
    register_sidebar(
        array(
            'name' => __( 'Various widgets', 'arwebstudio' ),
            'id' => 'sidebar-3',
            'description' => __( 'Appears when using the optional Front Page template with a page set as Static Front Page', 'arwebstudio' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>'
        )
    );
    register_sidebar(
        array(
            'name' => __( 'Search Form Widget Area', 'arwebstudio' ),
            'id' => 'sidebar-4',
            'description' => __( 'Search Form Widget Area', 'arwebstudio' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>'
        )
    );
    register_sidebar(
        array(
            'name' => __( 'First Widget area in the footer', 'arwebstudio' ),
            'id' => 'sidebar-5',
            'description' => __( 'First Widget area in the footer', 'arwebstudio' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>'
        )
    );
    register_sidebar(
        array(
            'name' => __( 'Second Widget area in the footer', 'arwebstudio' ),
            'id' => 'sidebar-6',
            'description' => __( 'Second Widget area in the footer', 'arwebstudio' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>'
        )
    );
    register_sidebar(
        array(
            'name' => __( 'Third Widget area in the footer', 'arwebstudio' ),
            'id' => 'sidebar-7',
            'description' => __( 'Third Widget area in the footer', 'arwebstudio' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>'
        )
    );
}
add_action( 'widgets_init', 'arwebstudio_widgets_init' );

if( ! function_exists( 'arwebstudio_content_nav' ) ) : 
function arwebstudio_content_nav($nav_id) {
    global $wp_query;
    $html_id = esc_attr($nav_id);
    if( $wp_query->max_num_pages > 1 ) : ?>
        <nav id="<?php echo $nav_id; ?>" class="navigation">
            <h3 class="accessibility"><?php _e( 'Post navigation', 'arwebstudio' ); ?></h3>
            <ul>
                <li class="prev-link alignleft"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'arwebstudio' )); ?></li>
                <li class="next-link alignright"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'arwebstudio' )); ?></li>
            </ul>
        </nav>
    <?php endif;
}
endif;

if( ! function_exists( 'arwebstudio_comment' ) ) : 
function arwebstudio_comment( $comment, $args, $depth ) {
    $GLOBALS['comment'] = $comment;
    switch ($comment->comment_type) :
        case 'pingback' :
        case 'trackback' : ?>
    <li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
        <p><?php _e( 'Pingback:', 'arwebstudio' ); comment_author_link(); edit_comment_link( __( 'Edit', 'arwebstudio' ), '<span class="edit-link">', '</span>' ); ?></p>
    <?php break;
        default :
        global $post; ?>
    <li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
        <article id="comment-<?php comment_ID(); ?>" class="comment">
            <header class="comment-meta comment-author vcard">
                <?php echo get_avatar( $comment, 44 );
                    printf( '<cite class="fn">%1$s %2$s</cite>',
                        get_comment_author_link(), (
                        $comment->user_id === $post->post_author) ? '<span> ' . __( 'Post author', 'arwebstudio' ) . '</span>' : ''
                    );
                    printf( '<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
                        esc_url( get_comment_link( $comment->comment_ID ) ),
                        get_comment_time( 'c' ),
                        sprintf( __( '%1$s at %2$s', 'arwebstudio' ), get_comment_date(), get_comment_time() )
                    ); ?>
            </header>
            <?php if( '0' == $comment->comment_approved ) : ?>
                <p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'arwebstudio' ); ?></p>
            <?php endif; ?>
            <section class="comment-content comment">
                <?php comment_text();
                edit_comment_link( __( 'Edit', 'arwebstudio' ), '<p class="edit-link">', '</p>' ); ?>
            </section>
            <div class="reply">
                <?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'arwebstudio' ), 'after' => ' <span>&darr;</span>', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
            </div>
        </article>
    <?php break;
    endswitch;
}
endif;

if( ! function_exists( 'arwebstudio_entry_meta' ) ) :
function arwebstudio_entry_meta() {
    $categories_list = get_the_category_list( __( ', ', 'arwebstudio' ) );
    $tag_list = get_the_tag_list( '', __( ', ', 'arwebstudio' ) );
    $date = sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><time class="post-date" datetime="%3$s">%4$s</time></a>',
        esc_url( get_permalink() ),
        esc_attr( get_the_time() ),
        esc_attr( get_the_date( 'c' ) ),
        esc_html( get_the_date() )
    );
    $author = sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
        esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
        esc_attr( sprintf( __( 'View all posts by %s', 'arwebstudio' ), get_the_author() ) ),
        get_the_author()
    );
    if( $tag_list ) {
        $utility_text = __( '<p class="cats">Categories: %1$s</p><p class="tags">Tags: %2$s</p><p class="date">%3$s</p> <p class="by-author">Author %4$s</p>', 'arwebstudio' );
    } elseif( $categories_list ) {
        $utility_text = __( '<p class="cats">Categories: %1$s</p><p class="tags">%3$s</p><p class="by-author">Author: %4$s</p>', 'arwebstudio' );
    } else {
        $utility_text = __( '%3$s <p class="by-author">Author: %4$s</p>', 'arwebstudio' );
    }
    printf(
        $utility_text,
        $categories_list,
        $tag_list,
        $date,
        $author
    );
}
endif;

function arwebstudio_body_class( $classes ) {
    $background_color = get_background_color();
    if( ! is_page_template( 'page-templates/full-width.php' ) ) {
        foreach( $classes as $key => $value ) {
            if( $value == 'full-width' ) unset( $classes[$key] );
        }
    }
    if( is_page_template( 'page-templates/front-page.php' ) ) {
        $classes[] = 'template-front-page';
        if( has_post_thumbnail() )
            $classes[] = 'has-post-thumbnail';
    }
    if( empty( $background_color ) )
        $classes[] = 'custom-background-empty';
    elseif( in_array( $background_color, array( 'fff', 'a73511' ) ) )
        $classes[] = 'custom-background-white';
    if( wp_style_is( 'arwebstudio-fonts', 'queue' ) )
        $classes[] = 'custom-font-enabled';
    if( ! is_multi_author() )
        $classes[] = 'single-author';
    return $classes;
}
add_filter( 'body_class', 'arwebstudio_body_class' );

function arwebstudio_content_width() {
    if( is_page_template( 'page-templates/full-width.php' ) || is_attachment() || ! is_active_sidebar( 'sidebar-1' ) ) {
        global $content_width;
        $content_width = 960;
    }
}
add_action( 'template_redirect', 'arwebstudio_content_width' );

function arwebstudio_customize_register( $wp_customize ) {
    $wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
    $wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';
}
add_action( 'customize_register', 'arwebstudio_customize_register' );

function arwebstudio_customize_preview_js() {
    wp_enqueue_script( 'arwebstudio-customizer', get_template_directory_uri() . '/js/theme-customizer.js', array( 'customize-preview' ), '20120827', TRUE );
}
add_action( 'customize_preview_init', 'arwebstudio_customize_preview_js' );